@@ -36,7 +36,7 @@ struct _GAllocator /* from gmem.c */
 };
 
 static GAllocator	*current_allocator = NULL;
-G_LOCK_DECLARE_STATIC (current_allocator);
+G_LOCK_DEFINE_STATIC (current_allocator);
 
 /* HOLDS: current_allocator_lock */
 static void
@@ -102,7 +102,7 @@ g_list_alloc (void)
   if (!current_allocator)
     {
       GAllocator *allocator = g_allocator_new ("GLib default GList allocator",
-					       1024);
+					       128);
       g_list_validate_allocator (allocator);
       allocator->last = NULL;
       current_allocator = allocator;
