@@ -35,7 +35,7 @@ struct _GAllocator /* from gmem.c */
   GSList        *free_lists; /* implementation specific */
 };
 
-G_LOCK_DECLARE_STATIC (current_allocator);
+G_LOCK_DEFINE_STATIC (current_allocator);
 static GAllocator       *current_allocator = NULL;
 
 /* HOLDS: current_allocator_lock */
@@ -102,7 +102,7 @@ g_slist_alloc (void)
   if (!current_allocator)
     {
       GAllocator *allocator = g_allocator_new ("GLib default GSList allocator",
-					       1024);
+					       128);
       g_slist_validate_allocator (allocator);
       allocator->last = NULL;
       current_allocator = allocator; 
